==> cscec5b-ecxj-impl-3.0.0-20230403.024840-5-sources.jar: com/ejianc/business/ecxj/bean/NoticeProductEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 比选通知商品实体（明细）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_notice_product")
public class NoticeProductEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private Long noticeId; // 比选通知单据主表主键ID
    @TableField(value="tender_product_id")
    private Long tenderProductId; // 云筑商品Id
    @TableField(value="product_name")
    private String productName; // 商品名称
    @TableField(value="product_spec")
    private String productSpec; // 规格型号
    @TableField(value="product_unit")
    private String productUnit; // 计量单位
    @TableField(value="tender_num")
    private BigDecimal tenderNum; // 招标数量

    @TableField(exist = false)
    @SubEntity(serviceName = "noticeSupplierService",pidName = "productId")
    private List<NoticeSupplierEntity> noticeSupplierEntities = new ArrayList<>(); // 物资中的供应商清单实体



    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }

    public Long getTenderProductId() {
        return tenderProductId;
    }

    public void setTenderProductId(Long tenderProductId) {
        this.tenderProductId = tenderProductId;
    }

    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getProductSpec() {
        return productSpec;
    }

    public void setProductSpec(String productSpec) {
        this.productSpec = productSpec;
    }
    public String getProductUnit() {
        return productUnit;
    }

    public void setProductUnit(String productUnit) {
        this.productUnit = productUnit;
    }
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }

    public List<NoticeSupplierEntity> getNoticeSupplierEntities() {
        return noticeSupplierEntities;
    }

    public void setNoticeSupplierEntities(List<NoticeSupplierEntity> noticeSupplierEntities) {
        this.noticeSupplierEntities = noticeSupplierEntities;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20230509.073540-32-sources.jar: com/ejianc/business/ecxj/bean/NoticeProductEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 比选通知商品实体（明细）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_notice_product")
public class NoticeProductEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="supplier_id")
    private Long supplierId; // 比选通知物资主键ID（子表主键）
    @TableField(value="setting_product_id")
    private Long settingProductId; // 云筑商品Id
    @TableField(value="tender_product_id")
    private Long tenderProductId; // 云筑商品Id
    @TableField(value="product_name")
    private String productName; // 商品名称
    @TableField(value="product_spec")
    private String productSpec; // 规格型号
    @TableField(value="product_unit")
    private String productUnit; // 计量单位
    @TableField(value="tender_num")
    private BigDecimal tenderNum; // 招标数量


    @TableField(value="product_price")
    private String productPrice; // 云筑网，单价/下浮率
    @TableField(value="product_rate")
    private String productRate; // 税率，云筑网
    @TableField(value="fill_price")
    private BigDecimal fillPrice; // 税前单价/下浮率（填报）


    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public Long getSettingProductId() {
        return settingProductId;
    }

    public void setSettingProductId(Long settingProductId) {
        this.settingProductId = settingProductId;
    }
    public Long getTenderProductId() {
        return tenderProductId;
    }

    public void setTenderProductId(Long tenderProductId) {
        this.tenderProductId = tenderProductId;
    }
    public String getProductName() {
        return productName;
    }

    public void setProductName(String productName) {
        this.productName = productName;
    }
    public String getProductSpec() {
        return productSpec;
    }

    public void setProductSpec(String productSpec) {
        this.productSpec = productSpec;
    }
    public String getProductUnit() {
        return productUnit;
    }

    public void setProductUnit(String productUnit) {
        this.productUnit = productUnit;
    }
    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }
    public String getProductPrice() {
        return productPrice;
    }

    public void setProductPrice(String productPrice) {
        this.productPrice = productPrice;
    }
    public String getProductRate() {
        return productRate;
    }

    public void setProductRate(String productRate) {
        this.productRate = productRate;
    }
    public BigDecimal getFillPrice() {
        return fillPrice;
    }

    public void setFillPrice(BigDecimal fillPrice) {
        this.fillPrice = fillPrice;
    }
}
